ContainerPositionExt

Trait ContainerPositionExt 

pub trait ContainerPositionExt
where Self: LayoutExt,
{ // Provided method fn position(self, position: impl Into<Position>) -> Self { ... } }
Method for setting how an element is placed relative to its parent or the window.

Provided Methods

fn position(self, position: impl Into<Position>) -> Self

Set how the element is placed relative to its parent or the window. See [Position].

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors